@@ -1,8 +1,10 @@
 import sys
 from typing import Optional
 
+from subete import Repo
+
+from generate_docs.how_to import HowTo
 from generate_docs.readme import ReadMeCatalog
-from generate_docs.repo import Repo
 from generate_docs.wiki import Wiki
 
 
@@ -10,6 +12,7 @@ class Generator:
     """
     The top-level class used to generate wiki and README objects.
     """
+
     def __init__(self, source_dir):
         self.source_dir = source_dir
         self.repo: Repo = Repo(self.source_dir)
@@ -62,6 +65,12 @@ def main_readmes():
     _create_generator().generate_readmes()
 
 
+def main_how_to():
+    how_to = HowTo()
+    how_to.page.output_page("")
+
+
 if __name__ == '__main__':
     main_wiki()
     main_readmes()
+    main_how_to()
